/* ISC license. */

#ifndef SHA512_INTERNAL_H
#define SHA512_INTERNAL_H

#include <skalibs/sha512.h>

extern void sha512_transform (SHA512Schedule *, unsigned char const *) ;

#endif
